pub trait SharesChannel { }Expand description
Marker trait for subscriptions that share a channel based on message type
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait SharesChannel { }Marker trait for subscriptions that share a channel based on message type
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".