pub enum TickType {
Show 106 variants
Unknown = -1,
BidSize = 0,
Bid = 1,
Ask = 2,
AskSize = 3,
Last = 4,
LastSize = 5,
High = 6,
Low = 7,
Volume = 8,
Close = 9,
BidOption = 10,
AskOption = 11,
LastOption = 12,
ModelOption = 13,
Open = 14,
Low13Week = 15,
High13Week = 16,
Low26Week = 17,
High26Week = 18,
Low52Week = 19,
High52Week = 20,
AvgVolume = 21,
OpenInterest = 22,
OptionHistoricalVol = 23,
OptionImpliedVol = 24,
OptionBidExch = 25,
OptionAskExch = 26,
OptionCallOpenInterest = 27,
OptionPutOpenInterest = 28,
OptionCallVolume = 29,
OptionPutVolume = 30,
IndexFuturePremium = 31,
BidExch = 32,
AskExch = 33,
AuctionVolume = 34,
AuctionPrice = 35,
AuctionImbalance = 36,
MarkPrice = 37,
BidEfpComputation = 38,
AskEfpComputation = 39,
LastEfpComputation = 40,
OpenEfpComputation = 41,
HighEfpComputation = 42,
LowEfpComputation = 43,
CloseEfpComputation = 44,
LastTimestamp = 45,
Shortable = 46,
FundamentalRatios = 47,
RtVolume = 48,
Halted = 49,
BidYield = 50,
AskYield = 51,
LastYield = 52,
CustOptionComputation = 53,
TradeCount = 54,
TradeRate = 55,
VolumeRate = 56,
LastRthTrade = 57,
RtHistoricalVol = 58,
IbDividends = 59,
BondFactorMultiplier = 60,
RegulatoryImbalance = 61,
NewsTick = 62,
ShortTermVolume3Min = 63,
ShortTermVolume5Min = 64,
ShortTermVolume10Min = 65,
DelayedBid = 66,
DelayedAsk = 67,
DelayedLast = 68,
DelayedBidSize = 69,
DelayedAskSize = 70,
DelayedLastSize = 71,
DelayedHigh = 72,
DelayedLow = 73,
DelayedVolume = 74,
DelayedClose = 75,
DelayedOpen = 76,
RtTrdVolume = 77,
CreditmanMarkPrice = 78,
CreditmanSlowMarkPrice = 79,
DelayedBidOption = 80,
DelayedAskOption = 81,
DelayedLastOption = 82,
DelayedModelOption = 83,
LastExch = 84,
LastRegTime = 85,
FuturesOpenInterest = 86,
AvgOptVolume = 87,
DelayedLastTimestamp = 88,
ShortableShares = 89,
DelayedHalted = 90,
Reuters2MutualFunds = 91,
EtfNavClose = 92,
EtfNavPriorClose = 93,
EtfNavBid = 94,
EtfNavAsk = 95,
EtfNavLast = 96,
EtfFrozenNavLast = 97,
EtfNavHigh = 98,
EtfNavLow = 99,
SocialMarketAnalytics = 100,
EstimatedIpoMidpoint = 101,
FinalIpoLast = 102,
DelayedYieldBid = 103,
DelayedYieldAsk = 104,
}Expand description
Market data tick types available from the TWS API.
These represent different types of market data that can be requested and received from Interactive Brokers. Each tick type corresponds to a specific piece of market information like bid, ask, last trade, volume, etc.
Variants
Unknown = -1
Unknown or invalid tick type.
BidSize = 0
Number of contracts or shares offered at the bid price.
Bid = 1
Highest price a buyer is willing to pay.
Ask = 2
Lowest price a seller is willing to accept.
AskSize = 3
Number of contracts or shares offered at the ask price.
Last = 4
Price of the last trade.
LastSize = 5
Number of contracts or shares traded in the last trade.
High = 6
Highest price of the day.
Low = 7
Lowest price of the day.
Volume = 8
Total trading volume for the day.
Close = 9
Previous day’s closing price.
BidOption = 10
Bid price for options.
AskOption = 11
Ask price for options.
LastOption = 12
Last traded price for options.
ModelOption = 13
Model-based option price.
Open = 14
Opening price of the day.
Low13Week = 15
Lowest price in the last 13 weeks.
High13Week = 16
Highest price in the last 13 weeks.
Low26Week = 17
Lowest price in the last 26 weeks.
High26Week = 18
Highest price in the last 26 weeks.
Low52Week = 19
Lowest price in the last 52 weeks.
High52Week = 20
Highest price in the last 52 weeks.
AvgVolume = 21
Average daily trading volume.
OpenInterest = 22
Total number of outstanding contracts.
OptionHistoricalVol = 23
Historical volatility for options.
OptionImpliedVol = 24
Implied volatility for options.
OptionBidExch = 25
Exchange code from which the option bid quote originated.
OptionAskExch = 26
Exchange code from which the option ask quote originated.
OptionCallOpenInterest = 27
Current open interest for call options.
OptionPutOpenInterest = 28
Current open interest for put options.
OptionCallVolume = 29
Trading volume for call options.
OptionPutVolume = 30
Trading volume for put options.
IndexFuturePremium = 31
Premium of the index future over fair value.
BidExch = 32
Exchange code supplying the top-of-book bid.
AskExch = 33
Exchange code supplying the top-of-book ask.
AuctionVolume = 34
Shares/contracts offered during the auction.
AuctionPrice = 35
Indicative auction clearing price.
AuctionImbalance = 36
Imbalance between buy and sell interest in the auction.
MarkPrice = 37
Mark price (used for margining in futures).
BidEfpComputation = 38
Bid-side exchange for EFP (Exchange for Physical) computations.
AskEfpComputation = 39
Ask-side exchange for EFP computations.
LastEfpComputation = 40
Last trade exchange for EFP computations.
OpenEfpComputation = 41
Opening price exchange for EFP computations.
HighEfpComputation = 42
High price exchange for EFP computations.
LowEfpComputation = 43
Low price exchange for EFP computations.
CloseEfpComputation = 44
Closing price exchange for EFP computations.
LastTimestamp = 45
Timestamp (epoch seconds) for the last tick.
Shortable = 46
Number of shares available for shorting.
FundamentalRatios = 47
Fundamental ratios snapshot (PE, EPS, etc.).
RtVolume = 48
Real-time consolidated volume message.
Halted = 49
Indicates if trading is halted (0 = not halted, 1 = halted).
BidYield = 50
Yield computed from the bid price (fixed income).
AskYield = 51
Yield computed from the ask price (fixed income).
LastYield = 52
Yield of the last trade (fixed income).
CustOptionComputation = 53
Custom option computation values supplied by IB.
TradeCount = 54
Number of trades over the reporting interval.
TradeRate = 55
Trades per minute over the interval.
VolumeRate = 56
Volume per minute over the interval.
LastRthTrade = 57
Last regular trading hours trade details.
RtHistoricalVol = 58
Real-time historical volatility value.
IbDividends = 59
Projected dividend information.
BondFactorMultiplier = 60
Factor multiplier used for bonds.
RegulatoryImbalance = 61
Regulatory imbalance indicator from exchanges.
NewsTick = 62
Exchange-issued news headline.
ShortTermVolume3Min = 63
Short-term volume averaged over 3 minutes.
ShortTermVolume5Min = 64
Short-term volume averaged over 5 minutes.
ShortTermVolume10Min = 65
Short-term volume averaged over 10 minutes.
DelayedBid = 66
Delayed bid price.
DelayedAsk = 67
Delayed ask price.
DelayedLast = 68
Delayed last traded price.
DelayedBidSize = 69
Delayed bid size.
DelayedAskSize = 70
Delayed ask size.
DelayedLastSize = 71
Delayed last trade size.
DelayedHigh = 72
Delayed session high.
DelayedLow = 73
Delayed session low.
DelayedVolume = 74
Delayed volume.
DelayedClose = 75
Delayed session close.
DelayedOpen = 76
Delayed session open.
RtTrdVolume = 77
Real-time trade volume (aggregate).
CreditmanMarkPrice = 78
Credit manager mark price.
CreditmanSlowMarkPrice = 79
Credit manager slow mark price.
DelayedBidOption = 80
Delayed option bid computation.
DelayedAskOption = 81
Delayed option ask computation.
DelayedLastOption = 82
Delayed option last computation.
DelayedModelOption = 83
Delayed option model price.
LastExch = 84
Exchange code for the last trade.
LastRegTime = 85
Time of the last regular trade.
FuturesOpenInterest = 86
Open interest for futures contracts.
AvgOptVolume = 87
Average option volume over 90 days.
DelayedLastTimestamp = 88
Timestamp associated with delayed last price.
Number of shares available to short.
DelayedHalted = 90
Delayed trading halt status.
Reuters2MutualFunds = 91
Reuters mutual fund indicative value.
ETF net asset value (NAV) close.
Prior day ETF NAV close.
ETF NAV bid.
ETF NAV ask.
ETF NAV last.
Frozen ETF NAV last value.
Intraday high estimate for ETF NAV.
Intraday low estimate for ETF NAV.
SocialMarketAnalytics = 100
Social market analytics sentiment score.
EstimatedIpoMidpoint = 101
Estimated midpoint for an IPO.
FinalIpoLast = 102
Final pricing for an IPO.
DelayedYieldBid = 103
Delayed bid yield.
DelayedYieldAsk = 104
Delayed ask yield.