pub struct MarketDepth {
pub position: i32,
pub operation: i32,
pub side: i32,
pub price: f64,
pub size: f64,
}Expand description
Returns the order book.
Fields
position: i32The order book’s row being updated
operation: i32How to refresh the row: 0 - insert (insert this new order into the row identified by ‘position’)· 1 - update (update the existing order in the row identified by ‘position’)· 2 - delete (delete the existing order at the row identified by ‘position’).
side: i320 for ask, 1 for bid
price: f64The order’s price.
size: f64The order’s size.