pub struct MarketDepthL2 {
pub position: i32,
pub market_maker: String,
pub operation: i32,
pub side: i32,
pub price: f64,
pub size: f64,
pub smart_depth: bool,
}Expand description
Returns the order book.
Fields
position: i32The order book’s row being updated
market_maker: StringThe exchange holding the order if isSmartDepth is True, otherwise the MPID of the market maker
operation: i32How to refresh the row: 0 - insert (insert this new order into the row identified by ‘position’)· 1 - update (update the existing order in the row identified by ‘position’)· 2 - delete (delete the existing order at the row identified by ‘position’).
side: i320 for ask, 1 for bid
price: f64The order’s price.
size: f64The order’s size.
smart_depth: boolFlag indicating if this is smart depth response (aggregate data from multiple exchanges, v974+)