pub enum Action {
Buy,
Sell,
SellShort,
SellLong,
}Expand description
Identifies the side. Generally available values are BUY and SELL. Additionally, SSHORT and SLONG are available in some institutional-accounts only. For general account types, a SELL order will be able to enter a short position automatically if the order quantity is larger than your current long position. SSHORT is only supported for institutional account configured with Long/Short account segments or clearing with a separate account. SLONG is available in specially-configured institutional accounts to indicate that long position not yet delivered is being sold.
Variants
Buy
Buy-side order.
Sell
Sell-side order.
SellShort
SSHORT is only supported for institutional account configured with Long/Short account segments or clearing with a separate account.
SellLong
SLONG is available in specially-configured institutional accounts to indicate that long position not yet delivered is being sold.
Implementations