attach_adjustable_to_stop

Function attach_adjustable_to_stop 

pub fn attach_adjustable_to_stop(
    parent: &Order,
    attached_order_stop_price: f64,
    trigger_price: f64,
    adjusted_stop_price: f64,
) -> Order
An attached order that turns the parent order (a conventional STP order) into a STP order in the opposite direction when the trigger is hit.