box_top

Function box_top 

pub fn box_top(action: Action, quantity: f64) -> Order
A Box Top order executes as a market order at the current best price. If the order is only partially filled, the remainder is submitted as a limit order with the limit price equal to the price at which the filled portion of the order executed. Products: OPT Supported Exchanges: BOX