Execution

Struct Execution 

pub struct Execution {
Show 18 fields pub order_id: i32, pub client_id: i32, pub execution_id: String, pub time: String, pub account_number: String, pub exchange: String, pub side: String, pub shares: f64, pub price: f64, pub perm_id: i32, pub liquidation: i32, pub cumulative_quantity: f64, pub average_price: f64, pub order_reference: String, pub ev_rule: String, pub ev_multiplier: Option<f64>, pub model_code: String, pub last_liquidity: Liquidity,
}
Describes an order’s execution.

Fields

order_id: i32

The API client’s order Id. May not be unique to an account.

client_id: i32

The API client identifier which placed the order which originated this execution.

execution_id: String

The execution’s identifier. Each partial fill has a separate ExecId. A correction is indicated by an ExecId which differs from a previous ExecId in only the digits after the final period, e.g. an ExecId ending in “.02” would be a correction of a previous execution with an ExecId ending in “.01”

time: String

The execution’s server time.

account_number: String

The account to which the order was allocated.

exchange: String

The exchange where the execution took place.

side: String

Specifies if the transaction was buy or sale BOT for bought, SLD for sold

shares: f64

The number of shares filled.

price: f64

The order’s execution price excluding commissions.

perm_id: i32

The TWS order identifier. The PermId can be 0 for trades originating outside IB.

liquidation: i32

Identifies whether an execution occurred because of an IB-initiated liquidation.

cumulative_quantity: f64

Cumulative quantity.

average_price: f64

Average price. Used in regular trades, combo trades and legs of the combo. Does not include commissions.

order_reference: String

The OrderRef is a user-customizable string that can be set from the API or TWS and will be associated with an order for its lifetime.

ev_rule: String

The Economic Value Rule name and the respective optional argument. The two values should be separated by a colon. For example, aussieBond:YearsToExpiration=3. When the optional argument is not present, the first value will be followed by a colon.

ev_multiplier: Option<f64>

Tells you approximately how much the market value of a contract would change if the price were to change by 1. It cannot be used to get market value by multiplying the price by the approximate multiplier.

model_code: String

model code

last_liquidity: Liquidity

Liquidity type of the execution (requires TWS 968+ / API v973.05+).