ExecutionFilter

Struct ExecutionFilter 

pub struct ExecutionFilter {
    pub client_id: Option<i32>,
    pub account_code: String,
    pub time: String,
    pub symbol: String,
    pub security_type: String,
    pub exchange: String,
    pub side: String,
    pub last_n_days: i32,
    pub specific_dates: Vec<String>,
}
Filter criteria used to determine which execution reports are returned.

Fields

client_id: Option<i32>

The API client which placed the order.

account_code: String

The account to which the order was allocated to

time: String

Time from which the executions will be returned yyyymmdd hh:mm:ss Only those executions reported after the specified time will be returned.

symbol: String

The instrument’s symbol

security_type: String

The Contract’s security’s type (i.e. STK, OPT…)

exchange: String

The exchange at which the execution was produced

side: String

The Contract’s side (BUY or SELL)

last_n_days: i32

Filter executions from the last N days (0 = no filter).

specific_dates: Vec<String>

Filter executions for specific dates (format: yyyymmdd, e.g., “20260130”).