pub struct ScannerData {
pub rank: i32,
pub contract_details: ContractDetails,
pub leg: String,
}Expand description
Provides the data resulting from the market scanner request.
Fields
rank: i32The ranking position of the contract in the scanner sort.
contract_details: ContractDetailsThe contract matching the scanner subscription.
leg: StringDescribes the combo legs when the scanner is returning EFP.