WshEventFilterBuilder

Struct WshEventFilterBuilder 

pub struct WshEventFilterBuilder<'a, C> { /* private fields */ }
Builder for Wall Street Horizon events matching a JSON filter.

Implementations

Source

impl<'a, C> WshEventFilterBuilder<'a, C>

pub fn limit(self, limit: i32) -> Self

Cap the number of events returned. TWS allows at most 100.

Requires server_versions::WSH_EVENT_DATA_FILTERS_DATE.

pub fn auto_fill(self, auto_fill: AutoFill) -> Self

Ask TWS to fill event data for related contracts. See AutoFill.

Source

impl<'a> WshEventFilterBuilder<'a, Client>

pub fn subscribe(self) -> Result<Subscription<WshEventData>, Error>

Submit the request and return a subscription of matching events.

Examples
use ibapi::client::blocking::Client;

let client = Client::connect("127.0.0.1:4002", 100).expect("connection failed");

// See https://www.interactivebrokers.com/campus/ibkr-api-page/twsapi-doc/#wsheventdata-object
let subscription = client.wsh_event_data_by_filter("{}").limit(10).subscribe().expect("request failed");

for event in subscription.iter_data() {
    println!("{:?}", event.expect("decode error"));
}
Source

impl<'a> WshEventFilterBuilder<'a, Client>

pub async fn subscribe(self) -> Result<Subscription<WshEventData>, Error>

Submit the request and return a subscription of matching events.

Examples
use ibapi::Client;
use ibapi::subscriptions::r#async::SubscriptionItemStreamExt;
use futures::StreamExt;

#[tokio::main]
async fn main() {
    let client = Client::connect("127.0.0.1:4002", 100).await.expect("connection failed");

    // See https://www.interactivebrokers.com/campus/ibkr-api-page/twsapi-doc/#wsheventdata-object
    let mut subscription = client.wsh_event_data_by_filter("{}").limit(10).subscribe().await.expect("request failed");

    let mut events = subscription.filter_data();
    while let Some(event) = events.next().await {
        println!("{:?}", event.expect("decode error"));
    }
}