pub struct WshMetadata {
pub data_json: String,
}Expand description
Wall Street Horizon metadata containing configuration and setup information.
Fields
data_json: StringJSON string containing metadata information from Wall Street Horizon.