Display groups subscription support
Display Groups
This module provides functionality for subscribing to TWS Display Group events. Display Groups in TWS allow users to organize contracts into color-coded groups (e.g., Group 1 = Red, Group 2 = Orange, etc.).
When subscribed to a display group, you receive updates whenever the user changes the contract displayed in that group within TWS.
Modules
- blocking
- Blocking display group helpers powered by the synchronous transport.
Structs
- Display
Group Subscription - A subscription to display group events with the ability to update the displayed contract.
- Display
Group Update - Represents a display group update event from TWS.