Module historical

Module historical 

Historical market data models and client APIs.

Re-exports

pub use async::historical_data_streaming;
pub use async::HistoricalDataStreamingSubscription;
pub use async::TickSubscription;
pub use async::*;

Modules

async
Async historical market data API.
blocking
Blocking historical market data helpers powered by the synchronous transport.
sync
Synchronous historical market data API.

Structs

Bar
Bar describes the historical data bar.
Duration
Duration specifier used in historical data requests (e.g. 1 D).
HistogramEntry
Histogram bucket entry returned from reqHistogramData.
HistoricalData
Container for historical bar responses.
Schedule
Trading schedule describing sessions for a contract.
Session
Individual regular or special session entry.
TickAttributeBidAsk
Tick attributes accompanying bid/ask historical ticks.
TickAttributeLast
Tick attributes accompanying trade historical ticks.
TickBidAsk
The historical tick’s description. Used when requesting historical tick data with whatToShow = BID_ASK.
TickLast
The historical last tick’s description. Used when requesting historical tick data with whatToShow = TRADES.
TickMidpoint
The historical tick’s description. Used when requesting historical tick data with whatToShow = MIDPOINT
WhatToShowParseError
Error returned when parsing an invalid WhatToShow value.

Enums

BarSize
Request granularity for historical bars.
HistoricalBarUpdate
Update from historical data streaming with keepUpToDate=true.
HistoricalParseError
Errors surfaced while parsing historical market data parameters.
WhatToShow
Enumerates the data payload returned when requesting historical data.

Traits

TickDecoder
Trait implemented by historical tick types that can decode IB messages.
ToDuration
Helper trait to convert integer counts into Durations.