Historical market data models and client APIs.
Re-exports
pub use async::historical_data_streaming;pub use async::HistoricalDataStreamingSubscription;pub use async::TickSubscription;pub use async::*;
Modules
- async
- Async historical market data API.
- blocking
- Blocking historical market data helpers powered by the synchronous transport.
- sync
- Synchronous historical market data API.
Structs
- Bar
- Bar describes the historical data bar.
- Duration
- Duration specifier used in historical data requests (e.g.
1 D). - Histogram
Entry - Histogram bucket entry returned from
reqHistogramData. - Historical
Data - Container for historical bar responses.
- Schedule
- Trading schedule describing sessions for a contract.
- Session
- Individual regular or special session entry.
- Tick
Attribute BidAsk - Tick attributes accompanying bid/ask historical ticks.
- Tick
Attribute Last - Tick attributes accompanying trade historical ticks.
- Tick
BidAsk - The historical tick’s description. Used when requesting historical tick data with whatToShow = BID_ASK.
- Tick
Last - The historical last tick’s description. Used when requesting historical tick data with whatToShow = TRADES.
- Tick
Midpoint - The historical tick’s description. Used when requesting historical tick data with whatToShow = MIDPOINT
- What
ToShow Parse Error - Error returned when parsing an invalid
WhatToShowvalue.
Enums
- BarSize
- Request granularity for historical bars.
- Historical
BarUpdate - Update from historical data streaming with keepUpToDate=true.
- Historical
Parse Error - Errors surfaced while parsing historical market data parameters.
- What
ToShow - Enumerates the data payload returned when requesting historical data.
Traits
- Tick
Decoder - Trait implemented by historical tick types that can decode IB messages.
- ToDuration
- Helper trait to convert integer counts into
Durations.