pub struct OrderState {Show 30 fields
pub status: OrderStatusKind,
pub initial_margin_before: Option<f64>,
pub maintenance_margin_before: Option<f64>,
pub equity_with_loan_before: Option<f64>,
pub initial_margin_change: Option<f64>,
pub maintenance_margin_change: Option<f64>,
pub equity_with_loan_change: Option<f64>,
pub initial_margin_after: Option<f64>,
pub maintenance_margin_after: Option<f64>,
pub equity_with_loan_after: Option<f64>,
pub commission: Option<f64>,
pub minimum_commission: Option<f64>,
pub maximum_commission: Option<f64>,
pub commission_currency: String,
pub margin_currency: String,
pub initial_margin_before_outside_rth: Option<f64>,
pub maintenance_margin_before_outside_rth: Option<f64>,
pub equity_with_loan_before_outside_rth: Option<f64>,
pub initial_margin_change_outside_rth: Option<f64>,
pub maintenance_margin_change_outside_rth: Option<f64>,
pub equity_with_loan_change_outside_rth: Option<f64>,
pub initial_margin_after_outside_rth: Option<f64>,
pub maintenance_margin_after_outside_rth: Option<f64>,
pub equity_with_loan_after_outside_rth: Option<f64>,
pub suggested_size: Option<f64>,
pub reject_reason: String,
pub order_allocations: Vec<OrderAllocation>,
pub warning_text: String,
pub completed_time: String,
pub completed_status: String,
}Expand description
Provides an active order’s current state.
Fields
status: OrderStatusKindThe order’s current status. See OrderStatusKind.
initial_margin_before: Option<f64>The account’s current initial margin.
maintenance_margin_before: Option<f64>The account’s current maintenance margin
equity_with_loan_before: Option<f64>The account’s current equity with loan
initial_margin_change: Option<f64>The change of the account’s initial margin.
maintenance_margin_change: Option<f64>The change of the account’s maintenance margin
equity_with_loan_change: Option<f64>The change of the account’s equity with loan
initial_margin_after: Option<f64>The order’s impact on the account’s initial margin.
maintenance_margin_after: Option<f64>The order’s impact on the account’s maintenance margin
equity_with_loan_after: Option<f64>Shows the impact the order would have on the account’s equity with loan
commission: Option<f64>The order’s generated commission.
minimum_commission: Option<f64>The execution’s minimum commission.
maximum_commission: Option<f64>The executions maximum commission.
commission_currency: StringThe generated commission currency
margin_currency: StringMargin currency
initial_margin_before_outside_rth: Option<f64>The account’s current initial margin outside RTH
maintenance_margin_before_outside_rth: Option<f64>The account’s current maintenance margin outside RTH
equity_with_loan_before_outside_rth: Option<f64>The account’s current equity with loan outside RTH
initial_margin_change_outside_rth: Option<f64>The change of the account’s initial margin outside RTH
maintenance_margin_change_outside_rth: Option<f64>The change of the account’s maintenance margin outside RTH
equity_with_loan_change_outside_rth: Option<f64>The change of the account’s equity with loan outside RTH
initial_margin_after_outside_rth: Option<f64>The order’s impact on the account’s initial margin outside RTH
maintenance_margin_after_outside_rth: Option<f64>The order’s impact on the account’s maintenance margin outside RTH
equity_with_loan_after_outside_rth: Option<f64>Shows the impact the order would have on the account’s equity with loan outside RTH
suggested_size: Option<f64>Suggested order size
reject_reason: StringReject reason
order_allocations: Vec<OrderAllocation>Order allocations
warning_text: StringIf the order is warranted, a descriptive message will be provided.
completed_time: StringTimestamp when the order completed execution.
completed_status: StringFree-form descriptive status sent at completion (e.g. "Cancelled by Trader",
"Filled Size: 1"). For the canonical lifecycle state, use status.