pub struct NoticeStream { /* private fields */ }Expand description
A handle for receiving globally routed notices on the async transport.
If the channel lags (broadcaster wraps around because a subscriber didn’t
keep up), the missed items are skipped with a debug log and next resumes
from the most recent notice.
Implementations