pub fn record_response(message: String)Expand description
Records a response message for the current interaction
Adds a response to the most recent interaction started by record_request.
If no interaction has been started, this function does nothing.
Arguments
message- The response message received from the server
Example
use ibapi::trace::blocking;
blocking::record_request("REQ|123|AAPL|".to_string());
blocking::record_response("RESP|123|150.00|".to_string());
blocking::record_response("RESP|123|151.00|".to_string());